#pragma once
#ifndef _PYZMQ_CONSTANT_DEFS
#define _PYZMQ_CONSTANT_DEFS

#ifdef ZMQ_BUILD_DRAFT_API
    #define PYZMQ_DRAFT_API 1
#else
    #define PYZMQ_DRAFT_API 0
#endif

#define _PYZMQ_UNDEFINED (-9999)
#ifndef ZMQ_VERSION
    #define ZMQ_VERSION (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_VERSION_MAJOR
    #define ZMQ_VERSION_MAJOR (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_VERSION_MINOR
    #define ZMQ_VERSION_MINOR (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_VERSION_PATCH
    #define ZMQ_VERSION_PATCH (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_NOBLOCK
    #define ZMQ_NOBLOCK (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_DONTWAIT
    #define ZMQ_DONTWAIT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_POLLIN
    #define ZMQ_POLLIN (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_POLLOUT
    #define ZMQ_POLLOUT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_POLLERR
    #define ZMQ_POLLERR (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_POLLPRI
    #define ZMQ_POLLPRI (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SNDMORE
    #define ZMQ_SNDMORE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_STREAMER
    #define ZMQ_STREAMER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_FORWARDER
    #define ZMQ_FORWARDER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_QUEUE
    #define ZMQ_QUEUE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_IO_THREADS_DFLT
    #define ZMQ_IO_THREADS_DFLT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_MAX_SOCKETS_DFLT
    #define ZMQ_MAX_SOCKETS_DFLT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_POLLITEMS_DFLT
    #define ZMQ_POLLITEMS_DFLT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_THREAD_PRIORITY_DFLT
    #define ZMQ_THREAD_PRIORITY_DFLT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_THREAD_SCHED_POLICY_DFLT
    #define ZMQ_THREAD_SCHED_POLICY_DFLT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_CONNECTED
    #define ZMQ_EVENT_CONNECTED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_CONNECT_DELAYED
    #define ZMQ_EVENT_CONNECT_DELAYED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_CONNECT_RETRIED
    #define ZMQ_EVENT_CONNECT_RETRIED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_LISTENING
    #define ZMQ_EVENT_LISTENING (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_BIND_FAILED
    #define ZMQ_EVENT_BIND_FAILED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_ACCEPTED
    #define ZMQ_EVENT_ACCEPTED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_ACCEPT_FAILED
    #define ZMQ_EVENT_ACCEPT_FAILED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_CLOSED
    #define ZMQ_EVENT_CLOSED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_CLOSE_FAILED
    #define ZMQ_EVENT_CLOSE_FAILED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_DISCONNECTED
    #define ZMQ_EVENT_DISCONNECTED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_ALL
    #define ZMQ_EVENT_ALL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_MONITOR_STOPPED
    #define ZMQ_EVENT_MONITOR_STOPPED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_HANDSHAKE_FAILED_NO_DETAIL
    #define ZMQ_EVENT_HANDSHAKE_FAILED_NO_DETAIL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_HANDSHAKE_SUCCEEDED
    #define ZMQ_EVENT_HANDSHAKE_SUCCEEDED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_HANDSHAKE_FAILED_PROTOCOL
    #define ZMQ_EVENT_HANDSHAKE_FAILED_PROTOCOL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENT_HANDSHAKE_FAILED_AUTH
    #define ZMQ_EVENT_HANDSHAKE_FAILED_AUTH (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_UNSPECIFIED
    #define ZMQ_PROTOCOL_ERROR_ZMTP_UNSPECIFIED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_UNEXPECTED_COMMAND
    #define ZMQ_PROTOCOL_ERROR_ZMTP_UNEXPECTED_COMMAND (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_INVALID_SEQUENCE
    #define ZMQ_PROTOCOL_ERROR_ZMTP_INVALID_SEQUENCE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_KEY_EXCHANGE
    #define ZMQ_PROTOCOL_ERROR_ZMTP_KEY_EXCHANGE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_UNSPECIFIED
    #define ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_UNSPECIFIED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_MESSAGE
    #define ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_MESSAGE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_HELLO
    #define ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_HELLO (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_INITIATE
    #define ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_INITIATE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_ERROR
    #define ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_ERROR (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_READY
    #define ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_READY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_WELCOME
    #define ZMQ_PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_WELCOME (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_INVALID_METADATA
    #define ZMQ_PROTOCOL_ERROR_ZMTP_INVALID_METADATA (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_CRYPTOGRAPHIC
    #define ZMQ_PROTOCOL_ERROR_ZMTP_CRYPTOGRAPHIC (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZMTP_MECHANISM_MISMATCH
    #define ZMQ_PROTOCOL_ERROR_ZMTP_MECHANISM_MISMATCH (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZAP_UNSPECIFIED
    #define ZMQ_PROTOCOL_ERROR_ZAP_UNSPECIFIED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZAP_MALFORMED_REPLY
    #define ZMQ_PROTOCOL_ERROR_ZAP_MALFORMED_REPLY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZAP_BAD_REQUEST_ID
    #define ZMQ_PROTOCOL_ERROR_ZAP_BAD_REQUEST_ID (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZAP_BAD_VERSION
    #define ZMQ_PROTOCOL_ERROR_ZAP_BAD_VERSION (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZAP_INVALID_STATUS_CODE
    #define ZMQ_PROTOCOL_ERROR_ZAP_INVALID_STATUS_CODE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROTOCOL_ERROR_ZAP_INVALID_METADATA
    #define ZMQ_PROTOCOL_ERROR_ZAP_INVALID_METADATA (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_NOTIFY_CONNECT
    #define ZMQ_NOTIFY_CONNECT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_NOTIFY_DISCONNECT
    #define ZMQ_NOTIFY_DISCONNECT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_NULL
    #define ZMQ_NULL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PLAIN
    #define ZMQ_PLAIN (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_CURVE
    #define ZMQ_CURVE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_GSSAPI
    #define ZMQ_GSSAPI (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_GSSAPI_NT_HOSTBASED
    #define ZMQ_GSSAPI_NT_HOSTBASED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_GSSAPI_NT_USER_NAME
    #define ZMQ_GSSAPI_NT_USER_NAME (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_GSSAPI_NT_KRB5_PRINCIPAL
    #define ZMQ_GSSAPI_NT_KRB5_PRINCIPAL (_PYZMQ_UNDEFINED)
#endif

#ifndef EAGAIN
    #define EAGAIN (_PYZMQ_UNDEFINED)
#endif

#ifndef EINVAL
    #define EINVAL (_PYZMQ_UNDEFINED)
#endif

#ifndef EFAULT
    #define EFAULT (_PYZMQ_UNDEFINED)
#endif

#ifndef ENOMEM
    #define ENOMEM (_PYZMQ_UNDEFINED)
#endif

#ifndef ENODEV
    #define ENODEV (_PYZMQ_UNDEFINED)
#endif

#ifndef EMSGSIZE
    #define EMSGSIZE (_PYZMQ_UNDEFINED)
#endif

#ifndef EAFNOSUPPORT
    #define EAFNOSUPPORT (_PYZMQ_UNDEFINED)
#endif

#ifndef ENETUNREACH
    #define ENETUNREACH (_PYZMQ_UNDEFINED)
#endif

#ifndef ECONNABORTED
    #define ECONNABORTED (_PYZMQ_UNDEFINED)
#endif

#ifndef ECONNRESET
    #define ECONNRESET (_PYZMQ_UNDEFINED)
#endif

#ifndef ENOTCONN
    #define ENOTCONN (_PYZMQ_UNDEFINED)
#endif

#ifndef ETIMEDOUT
    #define ETIMEDOUT (_PYZMQ_UNDEFINED)
#endif

#ifndef EHOSTUNREACH
    #define EHOSTUNREACH (_PYZMQ_UNDEFINED)
#endif

#ifndef ENETRESET
    #define ENETRESET (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_HAUSNUMERO
    #define ZMQ_HAUSNUMERO (_PYZMQ_UNDEFINED)
#endif

#ifndef ENOTSUP
    #define ENOTSUP (_PYZMQ_UNDEFINED)
#endif

#ifndef EPROTONOSUPPORT
    #define EPROTONOSUPPORT (_PYZMQ_UNDEFINED)
#endif

#ifndef ENOBUFS
    #define ENOBUFS (_PYZMQ_UNDEFINED)
#endif

#ifndef ENETDOWN
    #define ENETDOWN (_PYZMQ_UNDEFINED)
#endif

#ifndef EADDRINUSE
    #define EADDRINUSE (_PYZMQ_UNDEFINED)
#endif

#ifndef EADDRNOTAVAIL
    #define EADDRNOTAVAIL (_PYZMQ_UNDEFINED)
#endif

#ifndef ECONNREFUSED
    #define ECONNREFUSED (_PYZMQ_UNDEFINED)
#endif

#ifndef EINPROGRESS
    #define EINPROGRESS (_PYZMQ_UNDEFINED)
#endif

#ifndef ENOTSOCK
    #define ENOTSOCK (_PYZMQ_UNDEFINED)
#endif

#ifndef EFSM
    #define EFSM (_PYZMQ_UNDEFINED)
#endif

#ifndef ENOCOMPATPROTO
    #define ENOCOMPATPROTO (_PYZMQ_UNDEFINED)
#endif

#ifndef ETERM
    #define ETERM (_PYZMQ_UNDEFINED)
#endif

#ifndef EMTHREAD
    #define EMTHREAD (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PAIR
    #define ZMQ_PAIR (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PUB
    #define ZMQ_PUB (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SUB
    #define ZMQ_SUB (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_REQ
    #define ZMQ_REQ (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_REP
    #define ZMQ_REP (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_DEALER
    #define ZMQ_DEALER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_ROUTER
    #define ZMQ_ROUTER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PULL
    #define ZMQ_PULL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PUSH
    #define ZMQ_PUSH (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_XPUB
    #define ZMQ_XPUB (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_XSUB
    #define ZMQ_XSUB (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_STREAM
    #define ZMQ_STREAM (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_XREP
    #define ZMQ_XREP (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_XREQ
    #define ZMQ_XREQ (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_UPSTREAM
    #define ZMQ_UPSTREAM (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_DOWNSTREAM
    #define ZMQ_DOWNSTREAM (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SERVER
    #define ZMQ_SERVER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_CLIENT
    #define ZMQ_CLIENT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_RADIO
    #define ZMQ_RADIO (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_DISH
    #define ZMQ_DISH (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_GATHER
    #define ZMQ_GATHER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SCATTER
    #define ZMQ_SCATTER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_DGRAM
    #define ZMQ_DGRAM (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PEER
    #define ZMQ_PEER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_CHANNEL
    #define ZMQ_CHANNEL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_IO_THREADS
    #define ZMQ_IO_THREADS (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_MAX_SOCKETS
    #define ZMQ_MAX_SOCKETS (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SOCKET_LIMIT
    #define ZMQ_SOCKET_LIMIT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_THREAD_PRIORITY
    #define ZMQ_THREAD_PRIORITY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_THREAD_SCHED_POLICY
    #define ZMQ_THREAD_SCHED_POLICY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_BLOCKY
    #define ZMQ_BLOCKY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_MSG_T_SIZE
    #define ZMQ_MSG_T_SIZE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_THREAD_AFFINITY_CPU_ADD
    #define ZMQ_THREAD_AFFINITY_CPU_ADD (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_THREAD_AFFINITY_CPU_REMOVE
    #define ZMQ_THREAD_AFFINITY_CPU_REMOVE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_THREAD_NAME_PREFIX
    #define ZMQ_THREAD_NAME_PREFIX (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_IDENTITY
    #define ZMQ_IDENTITY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SUBSCRIBE
    #define ZMQ_SUBSCRIBE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_UNSUBSCRIBE
    #define ZMQ_UNSUBSCRIBE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_LAST_ENDPOINT
    #define ZMQ_LAST_ENDPOINT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_TCP_ACCEPT_FILTER
    #define ZMQ_TCP_ACCEPT_FILTER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PLAIN_USERNAME
    #define ZMQ_PLAIN_USERNAME (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PLAIN_PASSWORD
    #define ZMQ_PLAIN_PASSWORD (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_CURVE_PUBLICKEY
    #define ZMQ_CURVE_PUBLICKEY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_CURVE_SECRETKEY
    #define ZMQ_CURVE_SECRETKEY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_CURVE_SERVERKEY
    #define ZMQ_CURVE_SERVERKEY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_ZAP_DOMAIN
    #define ZMQ_ZAP_DOMAIN (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_CONNECT_RID
    #define ZMQ_CONNECT_RID (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_GSSAPI_PRINCIPAL
    #define ZMQ_GSSAPI_PRINCIPAL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_GSSAPI_SERVICE_PRINCIPAL
    #define ZMQ_GSSAPI_SERVICE_PRINCIPAL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SOCKS_PROXY
    #define ZMQ_SOCKS_PROXY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_XPUB_WELCOME_MSG
    #define ZMQ_XPUB_WELCOME_MSG (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_ROUTING_ID
    #define ZMQ_ROUTING_ID (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_CONNECT_ROUTING_ID
    #define ZMQ_CONNECT_ROUTING_ID (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_BINDTODEVICE
    #define ZMQ_BINDTODEVICE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_FD
    #define ZMQ_FD (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_RECONNECT_IVL_MAX
    #define ZMQ_RECONNECT_IVL_MAX (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SNDTIMEO
    #define ZMQ_SNDTIMEO (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_RCVTIMEO
    #define ZMQ_RCVTIMEO (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SNDHWM
    #define ZMQ_SNDHWM (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_RCVHWM
    #define ZMQ_RCVHWM (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_MULTICAST_HOPS
    #define ZMQ_MULTICAST_HOPS (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_IPV4ONLY
    #define ZMQ_IPV4ONLY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_ROUTER_BEHAVIOR
    #define ZMQ_ROUTER_BEHAVIOR (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_TCP_KEEPALIVE
    #define ZMQ_TCP_KEEPALIVE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_TCP_KEEPALIVE_CNT
    #define ZMQ_TCP_KEEPALIVE_CNT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_TCP_KEEPALIVE_IDLE
    #define ZMQ_TCP_KEEPALIVE_IDLE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_TCP_KEEPALIVE_INTVL
    #define ZMQ_TCP_KEEPALIVE_INTVL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_DELAY_ATTACH_ON_CONNECT
    #define ZMQ_DELAY_ATTACH_ON_CONNECT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_XPUB_VERBOSE
    #define ZMQ_XPUB_VERBOSE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_EVENTS
    #define ZMQ_EVENTS (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_TYPE
    #define ZMQ_TYPE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_LINGER
    #define ZMQ_LINGER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_RECONNECT_IVL
    #define ZMQ_RECONNECT_IVL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_BACKLOG
    #define ZMQ_BACKLOG (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_ROUTER_MANDATORY
    #define ZMQ_ROUTER_MANDATORY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_FAIL_UNROUTABLE
    #define ZMQ_FAIL_UNROUTABLE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_ROUTER_RAW
    #define ZMQ_ROUTER_RAW (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_IMMEDIATE
    #define ZMQ_IMMEDIATE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_IPV6
    #define ZMQ_IPV6 (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_MECHANISM
    #define ZMQ_MECHANISM (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PLAIN_SERVER
    #define ZMQ_PLAIN_SERVER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_CURVE_SERVER
    #define ZMQ_CURVE_SERVER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_PROBE_ROUTER
    #define ZMQ_PROBE_ROUTER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_REQ_RELAXED
    #define ZMQ_REQ_RELAXED (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_REQ_CORRELATE
    #define ZMQ_REQ_CORRELATE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_CONFLATE
    #define ZMQ_CONFLATE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_ROUTER_HANDOVER
    #define ZMQ_ROUTER_HANDOVER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_TOS
    #define ZMQ_TOS (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_IPC_FILTER_PID
    #define ZMQ_IPC_FILTER_PID (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_IPC_FILTER_UID
    #define ZMQ_IPC_FILTER_UID (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_IPC_FILTER_GID
    #define ZMQ_IPC_FILTER_GID (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_GSSAPI_SERVER
    #define ZMQ_GSSAPI_SERVER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_GSSAPI_PLAINTEXT
    #define ZMQ_GSSAPI_PLAINTEXT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_HANDSHAKE_IVL
    #define ZMQ_HANDSHAKE_IVL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_XPUB_NODROP
    #define ZMQ_XPUB_NODROP (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_XPUB_MANUAL
    #define ZMQ_XPUB_MANUAL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_STREAM_NOTIFY
    #define ZMQ_STREAM_NOTIFY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_INVERT_MATCHING
    #define ZMQ_INVERT_MATCHING (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_XPUB_VERBOSER
    #define ZMQ_XPUB_VERBOSER (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_HEARTBEAT_IVL
    #define ZMQ_HEARTBEAT_IVL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_HEARTBEAT_TTL
    #define ZMQ_HEARTBEAT_TTL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_HEARTBEAT_TIMEOUT
    #define ZMQ_HEARTBEAT_TIMEOUT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_CONNECT_TIMEOUT
    #define ZMQ_CONNECT_TIMEOUT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_TCP_MAXRT
    #define ZMQ_TCP_MAXRT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_THREAD_SAFE
    #define ZMQ_THREAD_SAFE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_MULTICAST_MAXTPDU
    #define ZMQ_MULTICAST_MAXTPDU (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_VMCI_CONNECT_TIMEOUT
    #define ZMQ_VMCI_CONNECT_TIMEOUT (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_USE_FD
    #define ZMQ_USE_FD (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_GSSAPI_PRINCIPAL_NAMETYPE
    #define ZMQ_GSSAPI_PRINCIPAL_NAMETYPE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_GSSAPI_SERVICE_PRINCIPAL_NAMETYPE
    #define ZMQ_GSSAPI_SERVICE_PRINCIPAL_NAMETYPE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_MULTICAST_LOOP
    #define ZMQ_MULTICAST_LOOP (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_ROUTER_NOTIFY
    #define ZMQ_ROUTER_NOTIFY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_ZAP_ENFORCE_DOMAIN
    #define ZMQ_ZAP_ENFORCE_DOMAIN (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_AFFINITY
    #define ZMQ_AFFINITY (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_MAXMSGSIZE
    #define ZMQ_MAXMSGSIZE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_HWM
    #define ZMQ_HWM (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SWAP
    #define ZMQ_SWAP (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_MCAST_LOOP
    #define ZMQ_MCAST_LOOP (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_RECOVERY_IVL_MSEC
    #define ZMQ_RECOVERY_IVL_MSEC (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_VMCI_BUFFER_SIZE
    #define ZMQ_VMCI_BUFFER_SIZE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_VMCI_BUFFER_MIN_SIZE
    #define ZMQ_VMCI_BUFFER_MIN_SIZE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_VMCI_BUFFER_MAX_SIZE
    #define ZMQ_VMCI_BUFFER_MAX_SIZE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_RATE
    #define ZMQ_RATE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_RECOVERY_IVL
    #define ZMQ_RECOVERY_IVL (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SNDBUF
    #define ZMQ_SNDBUF (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_RCVBUF
    #define ZMQ_RCVBUF (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_RCVMORE
    #define ZMQ_RCVMORE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_MORE
    #define ZMQ_MORE (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SRCFD
    #define ZMQ_SRCFD (_PYZMQ_UNDEFINED)
#endif

#ifndef ZMQ_SHARED
    #define ZMQ_SHARED (_PYZMQ_UNDEFINED)
#endif



#endif // ifndef _PYZMQ_CONSTANT_DEFS
